"""Overrides default form fields."""

from django import forms


class DateField(forms.DateField):
    """A date field."""

    def __init__(self, *args, **kwargs):
        kwargs["widget"] = forms.DateInput(attrs={"type": "date"})
        super().__init__(*args, **kwargs)


class DateTimeField(forms.DateTimeField):
    """A datetime field."""

    def __init__(self, *args, **kwargs):
        kwargs["widget"] = forms.DateTimeInput(
            attrs={"type": "datetime-local"}
        )
        super().__init__(*args, **kwargs)


class TimeField(forms.TimeField):
    """A time field."""

    def __init__(self, *args, **kwargs):
        kwargs["widget"] = forms.TimeInput(attrs={"type": "time"})
        super().__init__(*args, **kwargs)



from django.test import SimpleTestCase
from .. import form_fields


class TestFieldsLoad(SimpleTestCase):
    """Test that each custom form field loads."""

    def test_date_field(self):
        """Test that the date field loads."""
        form_fields.DateField()

    def test_datetime_field(self):
        """Test that the datetime field loads."""
        form_fields.DateTimeField()

    def test_time_field(self):
        """Test that the time field loads."""
        form_fields.TimeField()
